import express from "express";
import mongoose from "mongoose";
import morgan from "morgan";
import httpStatus from "http-status";
import { router } from "./api/index";
import ApiError from "./config/apiError";
import { mongooseObj } from "./config/mongoDB";
import dotenv from "dotenv";
const app = express();

dotenv.config();

//Logger for terminal
app.use(morgan("dev"));

//Connection to Database
mongoose.set("strictQuery", false);
mongoose.set("runValidators", true);
mongoose.connect(mongooseObj.url, mongooseObj.options).then(() => {
  console.log("Connected to MongoDB");
});

app.use(express.json({ limit: "50mb" }));
app.use(
  express.urlencoded({ limit: "100mb", extended: true, parameterLimit: 50000 })
);

app.use((req, res, next) => {
  res.header("Access-Control-Allow-Origin", "*");
  res.header(
    "Access-Control-Allow-Headers",
    "Origin, X-Requested-With, Content-Type, Accept, Authorization"
  );
  if (req.method === "OPTIONS") {
    res.header("Access-Control-Allow-Methods", "PUT, POST, GET, PATCH, DELETE");
    res.status(httpStatus.OK).json({});
  }
  next();
});

app.use("/managment_api/", router);

app.use((req, res, next) => {
  const error = new ApiError("Page Not Found");
  error.status = httpStatus.NOT_FOUND;
  next(error);
});

app.use((error, req, res, next) => {
  res.status(error.status || httpStatus.INTERNAL_SERVER_ERROR);
  res.json({ error: { message: error.message } });
});

export default app;
